summaryrefslogtreecommitdiffstats
path: root/quanta/utility/quantacommon.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-31 13:30:22 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-31 13:30:22 -0600
commitda4097d57f460eed4814a1c37fbb76a76e19d421 (patch)
treeb6ef741955039fd648b7c33964a080c8f240204e /quanta/utility/quantacommon.cpp
parenta6421d953bee2eafa951c8b72b367527800fef37 (diff)
downloadtdewebdev-da4097d57f460eed4814a1c37fbb76a76e19d421.tar.gz
tdewebdev-da4097d57f460eed4814a1c37fbb76a76e19d421.zip
Rename KStandard for enhanced compatibility with KDE4
Diffstat (limited to 'quanta/utility/quantacommon.cpp')
-rw-r--r--quanta/utility/quantacommon.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/quanta/utility/quantacommon.cpp b/quanta/utility/quantacommon.cpp
index e7f9380d..db1ce345 100644
--- a/quanta/utility/quantacommon.cpp
+++ b/quanta/utility/quantacommon.cpp
@@ -287,12 +287,12 @@ int eCol){
return pos;
}
/** Returns a pointer to a KStandardDirs object usable for plugin searchup. type
is the plugin binary type (exe or lib). The returned pointer must be deleted by
the caller!! */
-KStandardDirs* QuantaCommon::pluginDirs(const char *type)
+TDEStandardDirs* QuantaCommon::pluginDirs(const char *type)
{
- KStandardDirs *dirs = new KStandardDirs();
+ TDEStandardDirs *dirs = new TDEStandardDirs();
dirs->addKDEDefaults();
for (uint i = 0; i < qConfig.pluginSearchPaths.count(); i++)
{
@@ -287,12 +287,12 @@ int eCol){
return pos;
}
-/** Returns a pointer to a KStandardDirs object usable for plugin searchup. type
+/** Returns a pointer to a TDEStandardDirs object usable for plugin searchup. type
is the plugin binary type (exe or lib). The returned pointer must be deleted by
the caller!! */